<a id="mypy-boto3-directconnect"></a>

# mypy-boto3-directconnect

[![PyPI - mypy-boto3-directconnect](https://img.shields.io/pypi/v/mypy-boto3-directconnect.svg?color=blue)](https://pypi.org/project/mypy-boto3-directconnect)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-directconnect.svg?color=blue)](https://pypi.org/project/mypy-boto3-directconnect)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dw/mypy-boto3-directconnect?color=blue)](https://pypistats.org/packages/mypy-boto3-directconnect)

![boto3.typed](https://github.com/vemel/mypy_boto3_builder/raw/master/logo.png)

Type annotations for
[boto3.DirectConnect 1.19.2](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/directconnect.html#DirectConnect)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-builder 6.0.2](https://github.com/vemel/mypy_boto3_builder).

More information can be found on
[boto3-stubs](https://pypi.org/project/boto3-stubs/) page and in
[mypy-boto3-directconnect docs](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_directconnect/)

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/vemel/mypy_boto3_builder/raw/master/demo.gif)

- [mypy-boto3-directconnect](#mypy-boto3-directconnect)
  - [How to install](#how-to-install)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Literals](#literals)
    - [Typed dictionaries](#typed-dictionaries)
  - [Versioning](#versioning)
  - [Documentation](#documentation)
  - [Support and contributing](#support-and-contributing)

<a id="how-to-install"></a>

## How to install

Install `boto3-stubs` for `DirectConnect` service.

```bash
python -m pip install boto3-stubs[directconnect]
```

<a id="usage"></a>

## Usage

<a id="vscode"></a>

### VSCode

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `boto-stubs[directconnect]` in your environment:
  `python -m pip install 'boto3-stubs[directconnect]'`

Both type checking and auto-complete should work for `DirectConnect` service.
No explicit type annotations required, write your `boto3` code as usual.

<a id="pycharm"></a>

### PyCharm

- Install `boto-stubs[directconnect]` in your environment:
  `python -m pip install 'boto3-stubs[directconnect]'`

Both type checking and auto-complete should work for `DirectConnect` service.
No explicit type annotations required, write your `boto3` code as usual.
Auto-complete can be slow on big projects or if you have a lot of installed
`boto3-stubs` submodules.

<a id="other-ides"></a>

### Other IDEs

Not tested, but as long as your IDE supports `mypy` or `pyright`, everything
should work.

<a id="mypy"></a>

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `boto-stubs[directconnect]` in your environment:
  `python -m pip install 'boto3-stubs[directconnect]'`
- Run `mypy` as usual

Type checking should work for `DirectConnect` service. No explicit type
annotations required, write your `boto3` code as usual.

<a id="pyright"></a>

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `boto-stubs[directconnect]` in your environment:
  `python -m pip install 'boto3-stubs[directconnect]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `DirectConnect` service. No explicit type
annotations required, write your `boto3` code as usual.

<a id="explicit-type-annotations"></a>

## Explicit type annotations

<a id="client-annotations"></a>

### Client annotations

`DirectConnectClient` provides annotations for `boto3.client("directconnect")`.

```python
import boto3

from mypy_boto3_directconnect import DirectConnectClient

client: DirectConnectClient = boto3.client("directconnect")

# now client usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: DirectConnectClient = session.client("directconnect")
```

<a id="paginators-annotations"></a>

### Paginators annotations

`mypy_boto3_directconnect.paginator` module contains type annotations for all
paginators.

```python
from mypy_boto3_directconnect import DirectConnectClient
from mypy_boto3_directconnect.paginator import (
    DescribeDirectConnectGatewayAssociationsPaginator,
    DescribeDirectConnectGatewayAttachmentsPaginator,
    DescribeDirectConnectGatewaysPaginator,
)

client: DirectConnectClient = boto3.client("directconnect")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
describe_direct_connect_gateway_associations_paginator: DescribeDirectConnectGatewayAssociationsPaginator = client.get_paginator("describe_direct_connect_gateway_associations")
describe_direct_connect_gateway_attachments_paginator: DescribeDirectConnectGatewayAttachmentsPaginator = client.get_paginator("describe_direct_connect_gateway_attachments")
describe_direct_connect_gateways_paginator: DescribeDirectConnectGatewaysPaginator = client.get_paginator("describe_direct_connect_gateways")
```

<a id="literals"></a>

### Literals

`mypy_boto3_directconnect.literals` module contains literals extracted from
shapes that can be used in user code for type checking.

```python
from mypy_boto3_directconnect.literals import (
    AddressFamilyType,
    BGPPeerStateType,
    BGPStatusType,
    ConnectionStateType,
    DescribeDirectConnectGatewayAssociationsPaginatorName,
    DescribeDirectConnectGatewayAttachmentsPaginatorName,
    DescribeDirectConnectGatewaysPaginatorName,
    DirectConnectGatewayAssociationProposalStateType,
    DirectConnectGatewayAssociationStateType,
    DirectConnectGatewayAttachmentStateType,
    DirectConnectGatewayAttachmentTypeType,
    DirectConnectGatewayStateType,
    GatewayTypeType,
    HasLogicalRedundancyType,
    InterconnectStateType,
    LagStateType,
    LoaContentTypeType,
    NniPartnerTypeType,
    VirtualInterfaceStateType,
    ServiceName,
    PaginatorName,
)

def check_value(value: AddressFamilyType) -> bool:
    ...
```

<a id="typed-dictionaries"></a>

### Typed dictionaries

`mypy_boto3_directconnect.type_defs` module contains structures and shapes
assembled to typed dictionaries for additional type checking.

```python
from mypy_boto3_directconnect.type_defs import (
    AcceptDirectConnectGatewayAssociationProposalRequestRequestTypeDef,
    AcceptDirectConnectGatewayAssociationProposalResultTypeDef,
    AllocateConnectionOnInterconnectRequestRequestTypeDef,
    AllocateHostedConnectionRequestRequestTypeDef,
    AllocatePrivateVirtualInterfaceRequestRequestTypeDef,
    AllocatePublicVirtualInterfaceRequestRequestTypeDef,
    AllocateTransitVirtualInterfaceRequestRequestTypeDef,
    AllocateTransitVirtualInterfaceResultTypeDef,
    AssociateConnectionWithLagRequestRequestTypeDef,
    AssociateHostedConnectionRequestRequestTypeDef,
    AssociateMacSecKeyRequestRequestTypeDef,
    AssociateMacSecKeyResponseTypeDef,
    AssociateVirtualInterfaceRequestRequestTypeDef,
    AssociatedGatewayTypeDef,
    BGPPeerTypeDef,
    ConfirmConnectionRequestRequestTypeDef,
    ConfirmConnectionResponseTypeDef,
    ConfirmCustomerAgreementRequestRequestTypeDef,
    ConfirmCustomerAgreementResponseTypeDef,
    ConfirmPrivateVirtualInterfaceRequestRequestTypeDef,
    ConfirmPrivateVirtualInterfaceResponseTypeDef,
    ConfirmPublicVirtualInterfaceRequestRequestTypeDef,
    ConfirmPublicVirtualInterfaceResponseTypeDef,
    ConfirmTransitVirtualInterfaceRequestRequestTypeDef,
    ConfirmTransitVirtualInterfaceResponseTypeDef,
    ConnectionResponseMetadataTypeDef,
    ConnectionTypeDef,
    ConnectionsTypeDef,
    CreateBGPPeerRequestRequestTypeDef,
    CreateBGPPeerResponseTypeDef,
    CreateConnectionRequestRequestTypeDef,
    CreateDirectConnectGatewayAssociationProposalRequestRequestTypeDef,
    CreateDirectConnectGatewayAssociationProposalResultTypeDef,
    CreateDirectConnectGatewayAssociationRequestRequestTypeDef,
    CreateDirectConnectGatewayAssociationResultTypeDef,
    CreateDirectConnectGatewayRequestRequestTypeDef,
    CreateDirectConnectGatewayResultTypeDef,
    CreateInterconnectRequestRequestTypeDef,
    CreateLagRequestRequestTypeDef,
    CreatePrivateVirtualInterfaceRequestRequestTypeDef,
    CreatePublicVirtualInterfaceRequestRequestTypeDef,
    CreateTransitVirtualInterfaceRequestRequestTypeDef,
    CreateTransitVirtualInterfaceResultTypeDef,
    CustomerAgreementTypeDef,
    DeleteBGPPeerRequestRequestTypeDef,
    DeleteBGPPeerResponseTypeDef,
    DeleteConnectionRequestRequestTypeDef,
    DeleteDirectConnectGatewayAssociationProposalRequestRequestTypeDef,
    DeleteDirectConnectGatewayAssociationProposalResultTypeDef,
    DeleteDirectConnectGatewayAssociationRequestRequestTypeDef,
    DeleteDirectConnectGatewayAssociationResultTypeDef,
    DeleteDirectConnectGatewayRequestRequestTypeDef,
    DeleteDirectConnectGatewayResultTypeDef,
    DeleteInterconnectRequestRequestTypeDef,
    DeleteInterconnectResponseTypeDef,
    DeleteLagRequestRequestTypeDef,
    DeleteVirtualInterfaceRequestRequestTypeDef,
    DeleteVirtualInterfaceResponseTypeDef,
    DescribeConnectionLoaRequestRequestTypeDef,
    DescribeConnectionLoaResponseTypeDef,
    DescribeConnectionsOnInterconnectRequestRequestTypeDef,
    DescribeConnectionsRequestRequestTypeDef,
    DescribeCustomerMetadataResponseTypeDef,
    DescribeDirectConnectGatewayAssociationProposalsRequestRequestTypeDef,
    DescribeDirectConnectGatewayAssociationProposalsResultTypeDef,
    DescribeDirectConnectGatewayAssociationsRequestRequestTypeDef,
    DescribeDirectConnectGatewayAssociationsResultTypeDef,
    DescribeDirectConnectGatewayAttachmentsRequestRequestTypeDef,
    DescribeDirectConnectGatewayAttachmentsResultTypeDef,
    DescribeDirectConnectGatewaysRequestRequestTypeDef,
    DescribeDirectConnectGatewaysResultTypeDef,
    DescribeHostedConnectionsRequestRequestTypeDef,
    DescribeInterconnectLoaRequestRequestTypeDef,
    DescribeInterconnectLoaResponseTypeDef,
    DescribeInterconnectsRequestRequestTypeDef,
    DescribeLagsRequestRequestTypeDef,
    DescribeLoaRequestRequestTypeDef,
    DescribeRouterConfigurationRequestRequestTypeDef,
    DescribeRouterConfigurationResponseTypeDef,
    DescribeTagsRequestRequestTypeDef,
    DescribeTagsResponseTypeDef,
    DescribeVirtualInterfacesRequestRequestTypeDef,
    DirectConnectGatewayAssociationProposalTypeDef,
    DirectConnectGatewayAssociationTypeDef,
    DirectConnectGatewayAttachmentTypeDef,
    DirectConnectGatewayTypeDef,
    DisassociateConnectionFromLagRequestRequestTypeDef,
    DisassociateMacSecKeyRequestRequestTypeDef,
    DisassociateMacSecKeyResponseTypeDef,
    InterconnectResponseMetadataTypeDef,
    InterconnectTypeDef,
    InterconnectsTypeDef,
    LagResponseMetadataTypeDef,
    LagTypeDef,
    LagsTypeDef,
    ListVirtualInterfaceTestHistoryRequestRequestTypeDef,
    ListVirtualInterfaceTestHistoryResponseTypeDef,
    LoaResponseMetadataTypeDef,
    LoaTypeDef,
    LocationTypeDef,
    LocationsTypeDef,
    MacSecKeyTypeDef,
    NewBGPPeerTypeDef,
    NewPrivateVirtualInterfaceAllocationTypeDef,
    NewPrivateVirtualInterfaceTypeDef,
    NewPublicVirtualInterfaceAllocationTypeDef,
    NewPublicVirtualInterfaceTypeDef,
    NewTransitVirtualInterfaceAllocationTypeDef,
    NewTransitVirtualInterfaceTypeDef,
    PaginatorConfigTypeDef,
    ResourceTagTypeDef,
    ResponseMetadataTypeDef,
    RouteFilterPrefixTypeDef,
    RouterTypeTypeDef,
    StartBgpFailoverTestRequestRequestTypeDef,
    StartBgpFailoverTestResponseTypeDef,
    StopBgpFailoverTestRequestRequestTypeDef,
    StopBgpFailoverTestResponseTypeDef,
    TagResourceRequestRequestTypeDef,
    TagTypeDef,
    UntagResourceRequestRequestTypeDef,
    UpdateConnectionRequestRequestTypeDef,
    UpdateDirectConnectGatewayAssociationRequestRequestTypeDef,
    UpdateDirectConnectGatewayAssociationResultTypeDef,
    UpdateDirectConnectGatewayRequestRequestTypeDef,
    UpdateDirectConnectGatewayResponseTypeDef,
    UpdateLagRequestRequestTypeDef,
    UpdateVirtualInterfaceAttributesRequestRequestTypeDef,
    VirtualGatewayTypeDef,
    VirtualGatewaysTypeDef,
    VirtualInterfaceResponseMetadataTypeDef,
    VirtualInterfaceTestHistoryTypeDef,
    VirtualInterfaceTypeDef,
    VirtualInterfacesTypeDef,
)

def get_structure() -> AcceptDirectConnectGatewayAssociationProposalRequestRequestTypeDef:
    return {
      ...
    }
```

<a id="versioning"></a>

## Versioning

`mypy-boto3-directconnect` version is the same as related `boto3` version and
follows [PEP 440](https://www.python.org/dev/peps/pep-0440/) format.

<a id="documentation"></a>

## Documentation

All type annotations can be found in
[mypy-boto3-directconnect docs](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_directconnect/)

<a id="support-and-contributing"></a>

## Support and contributing

This package is auto-generated. Please reports any bugs or request new features
in [mypy-boto3-builder](https://github.com/vemel/mypy_boto3_builder/issues/)
repository.
